#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__='pepekiko@gmail.com'

from os import name
from copy import deepcopy

class Common(object):
    """
        Class with common methods/functions
    """ 
    def __init__(self):
        """
            Basic constructor
        """
        pass

    def get_slash(self):
        """
            Reference of S.O. returned values '\\' - Windows or '/' - Linux
        """
        if name == 'nt':
            return '\\'
        else:
            return '/'
        
    def doExtraLogger(self,appName:str,methodName:str,className:str,inheritedFrom:str,*args, **kwargs):
        """
            Public method used for construct dictionary with extra information for send to logger.
            :param appName: string
            :param methodName: string
            :param className: string
            :param inheritedFrom: string
            :param args: extra data
            :param kwargs: extra dictionary
        """
        extra = dict()
        extra["AppName"] = appName
        extra["Class"] = className
        extra["Method"] = methodName
        extra["inheritedFrom"] = inheritedFrom
        if kwargs:
            extra.update(kwargs['kwargs'])
        return extra

    def remove_property(self,target: dict,prop:[]) -> dict:
        """
            Method used for remove properties from a dictionary
            :param target: dict. Dictionary over that we can do changes
            :para prop: []. Properties of dictionary that we will remove inside.
        """        
        try:
            for p in prop:
                del target[p]
        except Exception:
            pass
        return target

    def object_to_dictionary(self,model:object)->dict:
        """
            Method used for convert model into dictionary
            :param model: object. Object over that we can do conversion to dictionary. Previously we do an copy and convert this copy.
        """ 
        result:dict = dict()       
        try:
            bck_model = deepcopy(model)
            result = bck_model.__dict__
        except Exception:
            pass
        return result


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__='pepekiko@gmail.com'

import json

class DictionaryReader(object):
    """
        This class provide a helper for convert json to dictionary and access to keys with attributes
    """
    def __init__(self, keys_dic = None, config_file = ()):
        """
            Class constructor
            :param keys_dic: dict. Dictionary with keys to search
            :param config_file: dict. Tuple with information. It´s required
        """
        self.__config_file = config_file
        if keys_dic == None:
            self.__keys = ()
        else:
            self.__keys = keys_dic
        self.__result = None

    def __getattr__(self,attribute):
        """
            Private method used for get attribute from class and create final endpoint.
            :param attribute: str. Parameter name
        """
        result = None
        try:            
            result = DictionaryReader(keys_dic=self.__keys + (attribute,),config_file=self.__config_file)
        except Exception as ex:
            pass
        return result

    def get(self,value_dict=None):
        """
            Public method for get value of dictionary
            :param value_dict: dict.
        """        
        try:
            if value_dict == None:
                dictionary_search = self.__config_file
            else:
                dictionary_search = value_dict
            for k in self.__keys:
                value = dictionary_search.get(k)
                if not value == None:
                    if isinstance(value,dict):
                        self.get(value_dict=value)
                    else:
                        if self.__result == None:
                            self.__result = value                       
        except Exception as ex:
            pass
        return self.__result